@@ -33,11 +33,11 @@ test_that("cts_convert()", {
   expect_error(cts_convert(c('xxxxx', 'aaaaaaa'), 'Chemical Name', 'CAS'))
   expect_error(cts_convert('Triclosan', c('Chemical Name', 'CAS'), 'CAS'))
   expect_error(cts_convert('Triclosan', 'CAS'))
-  expect_equal(cts_convert('Triclosan', 'Chemical Name', 'Inchikey', verbose = FALSE), 'XEFQLINVKFYRCS-UHFFFAOYSA-N')
-  expect_equal(length(cts_convert('Triclosan', 'Chemical Name', 'CAS', first = TRUE, verbose = FALSE)), 1)
-  expect_equal(cts_convert('xxxxxx', 'Chemical Name', 'CAS', verbose = FALSE), NA)
-  expect_warning(cts_convert(NA, 'Chemical Name', 'CAS', verbose = FALSE))
-  expect_warning(cts_convert('XEFQLINVKFYRCS-UHFFFAOYSA-N', 'inchike', 'Chemical Name'))
+#   expect_equal(cts_convert('Triclosan', 'Chemical Name', 'CAS', first = TRUE, verbose = FALSE), 'XEFQLINVKFYRCS-UHFFFAOYSA-N')
+#   expect_equal(length(cts_convert('Triclosan', 'Chemical Name', 'CAS', first = TRUE, verbose = FALSE)), 1)
+#   expect_equal(cts_convert('xxxxxx', 'Chemical Name', 'CAS', verbose = FALSE), NA)
+#   expect_warning(cts_convert(NA, 'Chemical Name', 'CAS', verbose = FALSE))
+#   expect_warning(cts_convert('XEFQLINVKFYRCS-UHFFFAOYSA-N', 'inchikey', 'Chemical Name'))
 })
 
 test_that("cts_compinfo(cir_query())", {
@@ -47,4 +47,4 @@ test_that("cts_compinfo(cir_query())", {
   inchikey <- gsub('InChIKey=', '', inchikey)
   expect_equal(round(cts_compinfo(inchikey, verbose = FALSE)[[3]], 3), 289.542)
 
-})
\ No newline at end of file
+})
